# Projeto: Pacote de Processamento de Imagens
## Autora do Projeto: Karina Kato
### Aula: Coding Lab PRO - Digital Innovation One

# package_name
image_processing:

- Módulo "Processing":
  - Correspondência de histograma;
  - Similaridade estrutural;
  - Redimensionar imagem;

- Módulo "Utils":
  - Ler imagem;
  - Salvar imagem;
  - Plotar imagem;
  - Resultado do gráfico;
  - Plotar histograma;

## Installation

Comandos para instalação:
```bash
pip install image_processing_abevilaqua
```
## Usage

```python
from image-processing.processing import transformation
transfer_histrogram(image1, image2)
```

## Author
Andre Bevilaqua

## License
[MIT](https://choosealicense.com/licenses/mit/)